@@ -34,13 +34,14 @@
 #'                                                 cannot be included. If the user does not provide a name for an expression, then the expression itself is used in the output. If this setting is provided, then \code{operation}, 
 #'                                                 \code{parName1}, \code{parName2}, \code{multPar1} and \code{multPar2} are
 #'                                                 ignored.
+#'                               \item \strong{\code{allPairs}}: Logical. If set to TRUE, Delta method calculations are carried out for the ratio and difference for all pairs of parameters and returned as two separate matrices with values and t-ratios. FALSE by default.
 #'                               \item \strong{\code{varcov}}: Character. Type of variance-covariance matrix to use in calculations. 
 #'                                                        It can take values \code{"classical"}, \code{"robust"} and 
 #'                                                        \code{"bootstrap"}. Default is \code{"robust"}.
+#'                               \item \strong{\code{printPVal}}: Logical or Scalar. TRUE or 1 for printing p-values for one-sided test, 2 for printing p-values for two-sided test, FALSE for not printing p-values. FALSE by default.
 #'                               \item \strong{\code{operation}}: Character. Function to calculate the delta method for. See details. Not used if \code{expression} is provided.
 #'                               \item \strong{\code{parName1}}: Character. Name of the first parameter if \code{operation} is used. See details. Not used if \code{expression} is provided.
 #'                               \item \strong{\code{parName2}}: Character. Name of the second parameter if \code{operation} is used. See details. Not used if \code{expression} is provided.. Optional depending on \code{operation}.
-#'                               \item \strong{\code{printPVal}}: Logical or Scalar. TRUE or 1 for printing p-values for one-sided test, 2 for printing p-values for two-sided test, FALSE for not printing p-values. FALSE by default.
 #'                               \item \strong{\code{multPar1}}: Numeric scalar. An optional value to scale \code{parName1}. Not used if \code{expression} is provided.
 #'                               \item \strong{\code{multPar2}}: Numeric scalar. An optional value to scale \code{parName2}. Not used if \code{expression} is provided.
 #'                             }
@@ -55,44 +56,48 @@ apollo_deltaMethod <- function(model, deltaMethod_settings){
   test <- is.list(model) && !is.null(names(model)) && !is.null(model$apollo_control)
   test <- test && any(c("varcov", "robvarcov", "bootvarcov") %in% names(model))
   test <- test && all("estimate" %in% names(model))
-  if(!test) stop("Input \"model\" is not a valid Apollo model object.")
+  if(!test) stop("INPUT ISSUE - Input \"model\" is not a valid Apollo model object.")
   test <- !is.null(model$apollo_control$HB) && !model$apollo_control$HB
-  if(!test) stop("The function \'apollo_deltaMethod\' is not applicables for models estimated using HB!")
+  if(!test) stop("INCORRECT FUNCTION/SETTING USE - The function \'apollo_deltaMethod\' is not applicables for models estimated using HB!")
   
   ### Validate settings
   test <- is.list(deltaMethod_settings) && !is.null(names(deltaMethod_settings))
-  if(!test) stop("Input \"deltaMethod_settings\" should be a named list. Type ?apollo_deltaMethod for help.")
+  if(!test) stop("INPUT ISSUE - Input \"deltaMethod_settings\" should be a non-empty named list. Type ?apollo_deltaMethod for help.")
+  if(is.null(deltaMethod_settings$allPairs)) deltaMethod_settings$allPairs=FALSE
+  allPairs=deltaMethod_settings$allPairs
   if(is.null(deltaMethod_settings[["varcov"]])) deltaMethod_settings[["varcov"]] <- "robust"
   if(is.null(deltaMethod_settings[["printPVal"]])) deltaMethod_settings[["printPVal"]] = FALSE
   test <- deltaMethod_settings[["varcov"]] %in% c("classical", "robust", "bootstrap")
-  if(!test) stop("Setting \"varcov\" can only take values \"classical\", \"robust\" or \"bootstrap\".")
+  if(!test) stop("SYNTAX ISSUE - Setting \"varcov\" can only take values \"classical\", \"robust\" or \"bootstrap\".")
   if(is.null(deltaMethod_settings[["expression"]])){
     # Checks if "expression" is not provided
-    nm <- names(deltaMethod_settings)
-    mandatory <- c("operation", "parName1")
-    for(i in mandatory) if(!(i %in% nm)) stop("The deltaMethod_settings list needs to include an element called \"", 
-                                              i, "\" if \"expression\" is not provided.")
-    nonMand <- c(parName1=NA, multPar1=1, multPar2=1)
-    for(i in names(nonMand)) if(!(i %in% nm)) deltaMethod_settings[[i]] <- nonMand[i]
-    rm(nm, mandatory, nonMand, i)
+    if(!allPairs){
+      nm <- names(deltaMethod_settings)
+      mandatory <- c("operation", "parName1")
+      for(i in mandatory) if(!(i %in% nm)) stop("SYNTAX ISSUE - The deltaMethod_settings list needs to include an element called \"", 
+                                                i, "\" if \"expression\" is not provided and \"allPairs=FALSE\".")
+      nonMand <- c(parName1=NA, multPar1=1, multPar2=1)
+      for(i in names(nonMand)) if(!(i %in% nm)) deltaMethod_settings[[i]] <- nonMand[i]
+      rm(nm, mandatory, nonMand, i)
+    }
   } else {
     # Checks if "expression" is provided
     e <- deltaMethod_settings[["expression"]]
     test <- is.vector(e) && is.character(e)
-    if(!test) stop("Element \"expression\" must be text.")
+    if(!test) stop("SYNTAX ISSUE - Element \"expression\" must be text.")
     tmp_e = e
     for(s in 1:length(tmp_e)){
       e <- tmp_e[s]
       e_name = ifelse((is.null(names(e))||names(e)==""),e,names(e))
       e <- tryCatch(as.expression(e), error=function(e) NULL)
-      if(is.null(e)) stop("The expression ",e_name," could not be parsed into a valid R expression.")
+      if(is.null(e)) stop("INTERNAL ISSUE - The expression ",e_name," could not be parsed into a valid R expression.")
       test <- all.vars(str2lang(deltaMethod_settings[["expression"]][s]))
       ### then expanded the below line
       test1 <- test[!(test %in% names(model$estimate))]
-      if(length(test1)>0) stop("The expression ",e_name," includes variables that are not parameters from the model: ",
+      if(length(test1)>0) stop("SYNTAX ISSUE - The expression ",e_name," includes variables that are not parameters from the model: ",
                                paste(test1, collapse=", "))
       test2 <- test[!(test %in% names(model$estimate)[!(names(model$estimate) %in% model$apollo_fixed)])]
-      if(length(test2)==length(test)) stop("The expression ",e_name," needs to include at least one parameter that was not fixed in estimation!")
+      if(length(test2)==length(test)) stop("SYNTAX ISSUE - The expression ",e_name," needs to include at least one parameter that was not fixed in estimation!")
       if(length(test2)>0){
         for(tmp in test2) tmp_e[s]=stringr::str_replace(tmp_e[s],tmp,as.character(model$estimate[tmp]))
         apollo_print(paste0("The expression ",e_name," includes parameters that were fixed in estimation: ",
@@ -114,10 +119,78 @@ apollo_deltaMethod <- function(model, deltaMethod_settings){
   if(vcov=="robust"   ) vcov <- "robvarcov"
   if(vcov=="bootstrap") vcov <- "bootvarcov"
   test <- vcov %in% names(model)
-  if(!test) stop("The requested variance covariance matrix cannot be found inside \"model\".")
+  if(!test) stop("INPUT ISSUE - The requested variance covariance matrix cannot be found inside \"model\".")
   vcov <- model[[vcov]]
   rm(test)
   
+  #### Processing for all pairs (if asked for) ####
+  if(allPairs){
+    cat("Running Delta method computation for all pairs of parameters\n\n")  
+    b_all <- model$estimate
+    b_est <- model$estimate[!(names(model$estimate) %in% model$apollo_fixed)]
+    ratios=data.frame(matrix(0,length(b_est),length(b_est)))
+    diffs=data.frame(matrix(0,length(b_all),length(b_all)))
+    ratios_se=data.frame(matrix(0,length(b_est),length(b_est)))
+    diffs_se=data.frame(matrix(0,length(b_all),length(b_all)))
+    ratios_trat=data.frame(matrix(0,length(b_est),length(b_est)))
+    diffs_trat=data.frame(matrix(0,length(b_all),length(b_all)))
+    for(k in 1:length(b_all)){
+      for(l in 1:length(b_all)){
+        if(k==l){
+          diffs[k,l]=0
+          diffs_se[k,l]=NA
+          diffs_trat[k,l]=NA
+        }else{
+          val=b_all[k]-b_all[l]
+          pos_1=which(names(b_est)==names(b_all)[k])
+          pos_2=which(names(b_est)==names(b_all)[l])
+          if((names(b_all)[k]%in%model$apollo_fixed)&(names(b_all)[l]%in%model$apollo_fixed)){
+            se=NA
+          }
+          if((names(b_all)[k]%in%model$apollo_fixed)&!(names(b_all)[l]%in%model$apollo_fixed)){
+            se=sqrt(vcov[pos_2,pos_2])
+          }
+          if(!(names(b_all)[k]%in%model$apollo_fixed)&(names(b_all)[l]%in%model$apollo_fixed)){
+            se=sqrt(vcov[pos_1,pos_1])
+          }
+          if(!(names(b_all)[k]%in%model$apollo_fixed)&!(names(b_all)[l]%in%model$apollo_fixed)){
+            se=sqrt(vcov[pos_1,pos_1]+vcov[pos_2,pos_2]-2*vcov[pos_1,pos_2])
+          }
+          diffs[k,l]=round(val,4)
+          diffs_se[k,l]=round(se,4)
+          diffs_trat[k,l]=round(val/se,2)
+        }
+      }
+    }
+    for(k in 1:length(b_est)){
+      for(l in 1:length(b_est)){
+        if(k==l){
+          ratios[k,l]=1
+          ratios_se[k,l]=NA
+          ratios_trat[k,l]=NA
+        }else{
+          val=b_est[k]/b_est[l]
+          se=sqrt(val^2*(vcov[k,k]/(b_est[k]^2)+vcov[l,l]/(b_est[l]^2)-2*vcov[k,l]/(b_est[k]*b_est[l])))
+          ratios[k,l]=round(val,4)
+          ratios_se[k,l]=round(se,4)
+          ratios_trat[k,l]=round(val/se,2)
+        }
+      }
+    }
+    colnames(ratios)=names(b_est)
+    rownames(ratios)=names(b_est)
+    colnames(ratios_se)=names(b_est)
+    rownames(ratios_se)=names(b_est)
+    colnames(ratios_trat)=names(b_est)
+    rownames(ratios_trat)=names(b_est)
+    colnames(diffs)=names(b_all)
+    rownames(diffs)=names(b_all)
+    colnames(diffs_se)=names(b_all)
+    rownames(diffs_se)=names(b_all)
+    colnames(diffs_trat)=names(b_all)
+    rownames(diffs_trat)=names(b_all)
+  }
+  
   #### Processing using expression ####
   if(!is.null(deltaMethod_settings[["expression"]])){
     # Useful functions
@@ -149,7 +222,7 @@ apollo_deltaMethod <- function(model, deltaMethod_settings){
       ###
       g <- insertAB(g, names(b))
       g <- setNames(g(b), names(b))
-      if(length(g)!=dim(vcov)[1]) stop("Dimensions of \"model$estimate\" and the covariance matrix do not match.")
+      if(length(g)!=dim(vcov)[1]) stop("INPUT ISSUE - Dimensions of \"model$estimate\" and the covariance matrix do not match.")
       # Prepare output
       return(data.frame(`Expression`     = ifelse((is.null(names(f))||names(f)==""),f,names(f)),
                        `Value`           = round(eval(str2lang(f), envir=list2env(as.list(b))),4),
@@ -173,10 +246,9 @@ apollo_deltaMethod <- function(model, deltaMethod_settings){
     }
     
     print(out,row.names=FALSE)
-    return(invisible(out))
   }
   
-  
+  if(!is.null(deltaMethod_settings[["operation"]])){
   #### Processing using operation ####
   ### SH bug fix 22 Dec - these 3 lines were missing
   if(is.null(deltaMethod_settings[["parName2"]])) deltaMethod_settings[["parName2"]]=NA
@@ -189,15 +261,15 @@ apollo_deltaMethod <- function(model, deltaMethod_settings){
   multPar1  = deltaMethod_settings[["multPar1"]]
   multPar2  = deltaMethod_settings[["multPar2"]]
   
-  if(parName1%in%model$apollo_fixed) stop(paste0("Parameter ",parName1," cannot be used with apollo_deltaMethod as it was fixed in estimation!"))
-  if(parName2%in%model$apollo_fixed) stop(paste0("Parameter ",parName2," cannot be used with apollo_deltaMethod as it was fixed in estimation!"))
+  if(parName1%in%model$apollo_fixed) stop(paste0("INPUT ISSUE - Parameter ",parName1," cannot be used with apollo_deltaMethod as it was fixed in estimation!"))
+  if(parName2%in%model$apollo_fixed) stop(paste0("INPUT ISSUE - Parameter ",parName2," cannot be used with apollo_deltaMethod as it was fixed in estimation!"))
   operation <- tolower(operation)
   
-  if( !(operation %in% c("sum","diff","ratio","exp","logistic","lognormal","prod")) ) stop("Invalid value of 'operation' parameter. See ?apollo_deltaMethod.")
-  if(is.na(parName2) & !(operation %in% c("logistic","exp"))) stop("Need two parameters if using operation: ",operation)
-  if(!(parName1 %in% names(model$estimate))) stop("parName1=", parName1, " not found among model estimates.")
-  if(!is.na(parName2) && !(parName2 %in% names(model$estimate))) stop("parName2=", parName2, " not found among model estimates.")
-  if(!is.na(parName2) & (operation=="exp")) stop("Should only have one parameters if using operation: ",operation)
+  if( !(operation %in% c("sum","diff","ratio","exp","logistic","lognormal","prod")) ) stop("SYNTAX ISSUE - Invalid value of 'operation' parameter. See ?apollo_deltaMethod.")
+  if(is.na(parName2) & !(operation %in% c("logistic","exp"))) stop("SYNTAX ISSUE - Need two parameters if using operation: ",operation)
+  if(!(parName1 %in% names(model$estimate))) stop("INPUT ISSUE - parName1=", parName1, " not found among model estimates.")
+  if(!is.na(parName2) && !(parName2 %in% names(model$estimate))) stop("INPUT ISSUE - parName2=", parName2, " not found among model estimates.")
+  if(!is.na(parName2) & (operation=="exp")) stop("SYNTAX ISSUE - Should only have one parameter if using operation: ",operation)
   
   est <- model$estimate
   if(!is.null(model$est)) est=model$est
@@ -312,5 +384,40 @@ apollo_deltaMethod <- function(model, deltaMethod_settings){
   cat("\nRunning Delta method computations\n")
   print(delta_output, digits=4)
   cat("\n")
-  return(invisible(delta_output))
+  }
+  
+  if(allPairs){
+    output=list()
+    if(!is.null(deltaMethod_settings[["expression"]])) output[["outputs"]]=out
+    if(!is.null(deltaMethod_settings[["operation"]])) output[["outputs"]]=delta_output
+    output[["ratios"]]=ratios
+    output[["ratios_se"]]=ratios_se
+    output[["ratios_trat"]]=ratios_trat
+    output[["diffs"]]=diffs
+    output[["diffs_se"]]=diffs_se
+    output[["diffs_trat"]]=diffs_trat
+    filename_ratios = paste(model$apollo_control$modelName,"_deltaMethod_ratios_value.csv",sep="")
+    filename_diffs = paste(model$apollo_control$modelName,"_deltaMethod_diffs_value.csv",sep="")
+    filename_ratios_se = paste(model$apollo_control$modelName,"_deltaMethod_ratios_se.csv",sep="")
+    filename_diffs_se = paste(model$apollo_control$modelName,"_deltaMethod_diffs_se.csv",sep="")
+    filename_ratios_trat = paste(model$apollo_control$modelName,"_deltaMethod_ratios_trat.csv",sep="")
+    filename_diffs_trat = paste(model$apollo_control$modelName,"_deltaMethod_diffs_trat.csv",sep="")
+    utils::write.csv(ratios, filename_ratios)
+    utils::write.csv(diffs, filename_diffs)
+    utils::write.csv(ratios_se, filename_ratios_se)
+    utils::write.csv(diffs_se, filename_diffs_se)
+    utils::write.csv(ratios_trat, filename_ratios_trat)
+    utils::write.csv(diffs_trat, filename_diffs_trat)
+    cat("\n\nValues for ratios for all pairs saved to ",filename_ratios,"\n",sep="")
+    cat("...Robust standard errors for ratios for all pairs saved to ",filename_ratios_se,"\n",sep="")
+    cat("...Robust t-ratios for ratios for all pairs saved to ",filename_ratios_trat,"\n",sep="")
+    cat("\n\nValues for differences for all pairs saved to ",filename_diffs,"\n",sep="")
+    cat("...Robust standard errors for differences for all pairs saved to ",filename_diffs_se,"\n",sep="")
+    cat("...Robust t-ratios for differences for all pairs saved to ",filename_diffs_trat,"\n",sep="")
+  }else{
+    if(!is.null(deltaMethod_settings[["expression"]])) output=out
+    if(!is.null(deltaMethod_settings[["operation"]]))  output=delta_output
+  }
+  apollo_print("\nThe results of the Delta method calculations are returned insibly as an output from this function. Calling the function via result=apollo_deltaMethod(...) will save this output in an object called result (or otherwise named object).", type="i")
+  return(invisible(output))
 }
