@@ -8,11 +8,13 @@
 #'                             \itemize{
 #'                               \item \strong{\code{printChange}}: Logical. TRUE for printing difference between starting values and estimates. FALSE by default.
 #'                               \item \strong{\code{printClassical}}: Logical. TRUE for printing classical standard errors. TRUE by default.
-#'                               \item \strong{\code{printCorr}}: Logical. TRUE for printing parameters correlation matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. FALSE by default.
-#'                               \item \strong{\code{printCovar}}: Logical. TRUE for printing parameters covariance matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. FALSE by default.
+#'                               \item \strong{\code{printCorr}}: Boolean. TRUE for printing parameters correlation matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. For Bayesian estimation, this setting is used for the covariane of random parameters. FALSE by default.
+#'                               \item \strong{\code{printCovar}}: Boolean. TRUE for printing parameters covariance matrix. If \code{printClassical=TRUE}, both classical and robust matrices are printed. For Bayesian estimation, this setting is used for the correlation of random parameters. FALSE by default.
 #'                               \item \strong{\code{printDataReport}}: Logical. TRUE for printing summary of choices in database and other diagnostics. FALSE by default.
 #'                               \item \strong{\code{printFixed}}: Logical. TRUE for printing fixed parameters among estimated parameter. TRUE by default.
 #'                               \item \strong{\code{printFunctions}}: Logical. TRUE for printing apollo_control, apollo_randCoeff (when available), apollo_lcPars (when available) and apollo_probabilities. FALSE by default.
+#'                               \item \strong{\code{printHBconvergence}}: Boolean. TRUE for printing Geweke convergence tests. FALSE by default.                               
+#'                               \item \strong{\code{printHBiterations}}: Boolean. TRUE for printing an iterations report for HB estimation. TRUE by default.                               
 #'                               \item \strong{\code{printModelStructure}}: Logical. TRUE for printing model structure. TRUE by default.
 #'                               \item \strong{\code{printOutliers}}: Logical or Scalar. TRUE for printing 20 individuals with worst average fit across observations. FALSE by default. If Scalar is given, this replaces the default of 20.
 #'                               \item \strong{\code{printPVal}}: Logical or Scalar. TRUE or 1 for printing p-values for one-sided test, 2 for printing p-values for two-sided test, FALSE for not printing p-values. FALSE by default.
@@ -35,11 +37,12 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   if(is.null(modelOutput_settings[["printT1"]])) modelOutput_settings[["printT1"]] = FALSE
   if(is.null(modelOutput_settings[["printCovar"]])) modelOutput_settings[["printCovar"]] = FALSE
   if(is.null(modelOutput_settings[["printCorr"]])) modelOutput_settings[["printCorr"]] = FALSE
+  if(is.null(modelOutput_settings[["printHBconvergence"]])) modelOutput_settings[["printHBconvergence"]] = FALSE
+  if(is.null(modelOutput_settings[["printHBiterations"]])) modelOutput_settings[["printHBiterations"]] = FALSE
   if(is.null(modelOutput_settings[["printOutliers"]])) modelOutput_settings[["printOutliers"]] = FALSE
   if(is.null(modelOutput_settings[["printChange"]])) modelOutput_settings[["printChange"]] = FALSE
   if(is.null(modelOutput_settings[["printFunctions"]])) modelOutput_settings[["printFunctions"]] = FALSE
   if(is.null(modelOutput_settings[["printFixed"]])) modelOutput_settings[["printFixed"]] = TRUE
-  if(is.null(modelOutput_settings[["printModifiedFunctions"]])) modelOutput_settings[["printModifiedFunctions"]] = FALSE
   
   printClassical   = modelOutput_settings[["printClassical"]]
   printPVal        = modelOutput_settings[["printPVal"]]
@@ -47,11 +50,12 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   printDiagnostics = modelOutput_settings[["printDiagnostics"]]
   printCovar       = modelOutput_settings[["printCovar"]]
   printCorr        = modelOutput_settings[["printCorr"]]
+  printHBconvergence = modelOutput_settings[["printHBconvergence"]]
+  printHBiterations = modelOutput_settings[["printHBiterations"]]
   printOutliers    = modelOutput_settings[["printOutliers"]]
   printChange      = modelOutput_settings[["printChange"]]
   printFunctions   = modelOutput_settings[["printFunctions"]]
   printFixed       = modelOutput_settings[["printFixed"]]
-  printModifiedFunctions = modelOutput_settings[["printModifiedFunctions"]]
   
   test <- !is.null(model$manualScaling) && length(model$manualScaling)==1 && is.logical(model$manualScaling)
   if(test) scaling_used <- model$manualScaling else {
@@ -86,7 +90,28 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   cat("Model description                           : ", model$apollo_control$modelDescr,"\n", sep="")
   cat("Model run at                                : ", paste(model$startTime),"\n", sep="")
   cat("Estimation method                           : ", model$estimationRoutine, "\n", sep="")
-  if(!apollo_control$HB) cat("Model diagnosis                             : ",model$message,"\n", sep="")
+  if(!apollo_control$HB){
+    cat("Model diagnosis                             : ",model$message,"\n", sep="")
+    if(!is.null(model$hessianEigenValue)){
+      isC  <- is.complex(model$hessianEigenValue)
+      anyZ <- !isC && any(model$hessianEigenValue==0)
+      anyN <- !isC && any(model$hessianEigenValue<0)
+      anyP <- !isC && any(model$hessianEigenValue>0)
+      if(isC) txt <- c("Non-symmetrical hessian", "Complex eigenvalues")
+      if(!isC && all(model$hessianEigenValue<0)) txt <- c("Maximum found", "Negative definitive")
+      if(!isC && anyZ) txt <- c("Inconclusive test", "Some eigenvalues are zero")
+      if(!isC && !anyZ && anyP && anyP) txt <- c("Saddle point found", "Some eigenvalues are positive and others negative")
+      if(!isC && all(model$hessianEigenValue>0)) txt <- c("Minimum found", "Positive definitive")
+      if(isC) txt[3] <- "NA" else txt[3] <- as.character(round(max(model$hessianEigenValue),6))
+      cat("Optimisation diagnosis                      : ", txt[1], "\n", 
+          "     hessian properties                     : ", txt[2], "\n", 
+          "     maximum eigenvalue                     : ", txt[3], "\n", sep="")
+      rm(isC, anyZ, anyN, anyP, txt)
+    } else if(!is.null(model$eigValue) && !anyNA(model$eigValue)){
+      cat("Min abs eigenvalue of Hessian               : ",round(min(abs(model$eigValue)),6),"\n")
+      if(any(model$eigValue>0)) apollo_print("Some eigenvalues of Hessian are positive, indicating potential problems!") 
+    }
+  }
   cat("Number of individuals                       : ", model$nIndivs,"\n", sep="")
   cat("Number of rows in database                  : ", model$nObs,"\n", sep="")
   if(!is.null(model$nObsTot)){
@@ -131,28 +156,28 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
     cat("\n")
     apollo_print("Classical model fit statistics were calculated at parameter values obtained using averaging across the post burn-in iterations.")
     cat("LL(start)                                   : ",round(model$LLStart,2),"\n", sep="")
-    if(length(model$LLout)==1) cat("LL at equal shares, LL(0)                   : ",ifelse(!anyNA(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
-    if(length(model$LLout)>1 ) cat("LL (whole model) at equal shares, LL(0)     : ",ifelse(!anyNA(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
-    if(length(model$LLout)==1) cat("LL at observed shares, LL(C)                : ",ifelse(!anyNA(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
-    if(length(model$LLout)>1 ) cat("LL (whole model) at observed shares, LL(C)  : ",ifelse(!anyNA(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
+    if(length(model$LLout)==1) cat("LL at equal shares, LL(0)                   : ",ifelse(is.numeric(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
+    if(length(model$LLout)>1 ) cat("LL (whole model) at equal shares, LL(0)     : ",ifelse(is.numeric(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
+    if(length(model$LLout)==1) cat("LL at observed shares, LL(C)                : ",ifelse(is.numeric(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
+    if(length(model$LLout)>1 ) cat("LL (whole model) at observed shares, LL(C)  : ",ifelse(is.numeric(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
     if(length(model$LLout)==1) cat("LL(final)                                   : ",round(model$maximum,2),"\n",sep="")
     if(length(model$LLout)>1 ) cat("LL(final, whole model)                      : ",round(model$maximum,2),"\n",sep="")
-    cat("Rho-squared vs equal shares                  : ", ifelse(anyNA(model$rho2_0   ), "Not applicable", round(model$rho2_0   , 4)),"\n")
-    cat("Adj.Rho-squared vs equal shares              : ", ifelse(anyNA(model$adjRho2_0), "Not applicable", round(model$adjRho2_0, 4)),"\n")
-    cat("Rho-squared vs observed shares               : ", ifelse(anyNA(model$rho2_C   ), "Not applicable", round(model$rho2_C   , 4)),"\n")
-    cat("Adj.Rho-squared vs observed shares           : ", ifelse(anyNA(model$adjRho2_C), "Not applicable", round(model$adjRho2_C, 4)),"\n")
+    cat("Rho-squared vs equal shares                  : ", ifelse(!is.numeric(model$rho2_0   ), "Not applicable", round(model$rho2_0   , 4)),"\n")
+    cat("Adj.Rho-squared vs equal shares              : ", ifelse(!is.numeric(model$adjRho2_0), "Not applicable", round(model$adjRho2_0, 4)),"\n")
+    cat("Rho-squared vs observed shares               : ", ifelse(!is.numeric(model$rho2_C   ), "Not applicable", round(model$rho2_C   , 4)),"\n")
+    cat("Adj.Rho-squared vs observed shares           : ", ifelse(!is.numeric(model$adjRho2_C), "Not applicable", round(model$adjRho2_C, 4)),"\n")
     cat("AIC                                         : ",round(model$AIC, 2),"\n")
     cat("BIC                                         : ",round(model$BIC, 2),"\n")
     cat("\n")
     cat("Equiv. estimated parameters                 :  ", model$nFreeParams,"\n", sep="")
-    if(model$nnonrandom>0){
-    cat(" (non-random parameters                     :  ", model$nnonrandom,")\n", sep="")
+    if(model$HB_n_nonrandom>0){
+    cat(" (non-random parameters                     :  ", model$HB_n_nonrandom,")\n", sep="")
     }
-    if(model$nrandom_means>0){
-    cat(" (means of random parameters                :  ", model$nrandom_means,")\n", sep="")
+    if(model$HB_n_random_means>0){
+    cat(" (means of random parameters                :  ", model$HB_n_random_means,")\n", sep="")
     }
-    if(model$nrandom_covar>0){
-    cat(" (covariance matrix terms                   :  ", model$nrandom_covar,")\n", sep="")
+    if(model$HB_n_random_covar>0){
+    cat(" (covariance matrix terms                   :  ", model$HB_n_random_covar,")\n", sep="")
     }
 
     if(length(model$LLout)>1){
@@ -185,88 +210,103 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
     cat("     post-estimation                        : ",f(model$timePost),"\n")
     cat("\n\n")
     
-    cat("Chain convergence report (Geweke test)\n\n")
-    if(!is.null(model[["F"]])){
-      cat("Fixed (non random) parameters (t-test value for Geweke test)\n")
-      #tmp <- coda::geweke.diag(model$F[,2:(ncol(model$F))], frac1=0.1, frac2=0.5)[[1]]
-      #names(tmp) <- model$params.fixed
-      #print( round(tmp, 4) )
-      print( round(model$F_convergence, 4) )
-      cat("\n")
-    }
-    if(!is.null(model[["A"]])){
-      cat("Random parameters (t-test value for Geweke test)\n")
-      #tmp <- coda::geweke.diag(model$A[,2:(ncol(model$A))], frac1=0.1, frac2=0.5)[[1]]
-      #print( round(tmp, 4) )
-      print( round(model$A_convergence, 4) )
-      cat("\n")
-    }
-    if(!is.null(model[["D"]])){
-      cat("Covariances of random parameters (t-test value for Geweke test)\n")
-      # This assumes the matrix is square
-      #tmp <- c()
-      #for(i in 1:dim(model$D)[1]) for(j in 1:i){
-      #  if(i==1 & j==1) Dmatrix <- as.matrix(model$D[i,j,]) else Dmatrix <- cbind(Dmatrix, as.vector(model$D[i,j,]))
-      #  tmp <- c(tmp, paste(colnames(model$A)[i+1],colnames(model$A)[j+1], sep="_"))
-      #}
-      #colnames(Dmatrix) <- tmp
-      #tmp <- coda::geweke.diag(Dmatrix, frac1=0.1, frac2=0.5)[[1]]
-      #print( round(tmp, 4) )
-      print( round(model$D_convergence, 4) )
-    }
-    cat("\n\n")
-    
     cat("Summary of parameter chains\n\n")
+    
     ans <- list()
     
     if(length(apollo_HB$gVarNamesFixed)>0 | length(model$apollo_fixed)>0){
       cat("Non-random coefficients","\n")
       if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n\n")
-      print(round(model$chain_non_random,4))
+      print(round(model$HB_chains_non_random,4))
       cat("\n")
-      ans[["non_random"]] <- model$chain_non_random
+      ans[["non_random"]] <- model$HB_chains_non_random
     }
     
-    apollo_HB$gVarNamesFixed <- model$params.fixed
-    apollo_HB$gVarNamesNormal <- model$params.vary
+    apollo_HB$gVarNamesFixed <- model$HB_names_nonrandom_params
+    apollo_HB$gVarNamesNormal <- model$HB_names_random_params
     if(any(!is.null(apollo_HB$gVarNamesNormal)) && length(apollo_HB$gVarNamesNormal)>0){
-      cat("Upper level model results for mean parameters for underlying Normals","\n")
-      if(scaling_used) cat("These outputs have NOT had the scaling used in estimation applied to them\n")
-      print(round(model$chain_random_mean,4))
-      cat("\n")
-      
-      cat("Upper level model results for covariance matrix for underlying Normals (means across iterations)","\n")
-      if(scaling_used) cat("These outputs have NOT had the scaling used in estimation applied to them\n")
-      print(round(model$chain_random_cov_mean,4))
-      cat("\n")
-      
-      cat("Upper level model results for covariance matrix for underlying Normals (SD across iterations)","\n")
-      if(scaling_used) cat("These outputs have NOT had the scaling used in estimation applied to them\n")
-      print(round(model$chain_random_cov_sd,4))
+      cat("Results for posterior means for random coefficients","\n")
+      if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
+      print(round(model$HB_posterior_means_summary,4))
       cat("\n")
       
       cat("Summary of distributions of random coeffients (after distributional transforms)","\n")
       if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
-      print(round(model$random_coeff_summary,4))
+      print(round(model$HB_random_params_mean_sd,4))
       cat("\n")
-      
+
       if(length(apollo_HB$gVarNamesNormal)>1){
-        cat("Covariance matrix of random coeffients (after distributional transforms)","\n")
-        if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
-        print(round(model$random_coeff_covar,4))
-        cat("\n")
-        
-        cat("Correlation matrix of random coeffients (after distributional transforms)","\n")
-        if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
-        print(round(model$random_coeff_corr,4))
-        cat("\n")
+        if(printCovar){
+          cat("Covariance matrix of random coeffients (after distributional transforms)","\n")
+          if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
+          print(round(model$HB_random_params_covar,4))
+          cat("\n")
+        }
+        if(printCorr){
+          cat("Correlation matrix of random coeffients (after distributional transforms)","\n")
+          if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
+          print(round(model$HB_random_params_corr,4))
+          cat("\n")
+        }
       }
       
-      
-      cat("Results for posterior means for random coefficients","\n")
-      if(scaling_used) cat("These outputs have had the scaling used in estimation applied to them\n")
-      print(round(model$posterior_mean,4))
+      cat("Upper level model results for mean parameters for underlying Normals","\n")
+      if(scaling_used) cat("These outputs have NOT had the scaling used in estimation applied to them\n")
+      print(round(model$HB_chains_normals_means,4))
       cat("\n")
+
+      if(printCovar){
+      cat("Upper level model results for covariance matrix for underlying Normals (means across iterations)","\n")
+      if(scaling_used) cat("These outputs have NOT had the scaling used in estimation applied to them\n")
+      print(round(model$HB_chains_normals_mean_of_covar,4))
+      cat("\n")
+      
+      cat("Upper level model results for covariance matrix for underlying Normals (SD across iterations)","\n")
+      if(scaling_used) cat("These outputs have NOT had the scaling used in estimation applied to them\n")
+      print(round(model$HB_chains_normals_sd_of_covar,4))
+      cat("\n")
+      }
+      
+     
+      
+      if(printHBconvergence){
+        cat("Chain convergence report (Geweke test)\n\n")
+        if(!is.null(model[["F"]])){
+          cat("Fixed (non random) parameters (t-test value for Geweke test)\n")
+          #tmp <- coda::geweke.diag(model$HB_iterations_non_random[,2:(ncol(model$HB_iterations_non_random))], frac1=0.1, frac2=0.5)[[1]]
+          #names(tmp) <- model$HB_names_nonrandom_params
+          #print( round(tmp, 4) )
+          print( round(model$HB_Geweke_test_non_random, 4) )
+          cat("\n")
+        }
+        if(!is.null(model[["A"]])){
+          cat("Random parameters (t-test value for Geweke test)\n")
+          #tmp <- coda::geweke.diag(model$HB_iterations_means[,2:(ncol(model$HB_iterations_means))], frac1=0.1, frac2=0.5)[[1]]
+          #print( round(tmp, 4) )
+          print( round(model$HB_Geweke_test_means, 4) )
+          cat("\n")
+        }
+        if(!is.null(model[["D"]])){
+          cat("Covariances of random parameters (t-test value for Geweke test)\n")
+          # This assumes the matrix is square
+          #tmp <- c()
+          #for(i in 1:dim(model$HB_iterations_covar)[1]) for(j in 1:i){
+          #  if(i==1 & j==1) Dmatrix <- as.matrix(model$HB_iterations_covar[i,j,]) else Dmatrix <- cbind(Dmatrix, as.vector(model$HB_iterations_covar[i,j,]))
+          #  tmp <- c(tmp, paste(colnames(model$HB_iterations_means)[i+1],colnames(model$HB_iterations_means)[j+1], sep="_"))
+          #}
+          #colnames(Dmatrix) <- tmp
+          #tmp <- coda::geweke.diag(Dmatrix, frac1=0.1, frac2=0.5)[[1]]
+          #print( round(tmp, 4) )
+          print( round(model$HB_Geweke_test_covar, 4) )
+        }
+        cat("\n\n")
+      }
+      
+      if(printHBiterations){
+        cat("\nIteration details (overview)")
+        cat("\n----------------------------\n")
+        print(model[["HB_iterations_detail"]], row.names = FALSE)
+      }
       
       ### 3 Feb
       
@@ -282,23 +322,60 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
         colnames(txt)="Value"
         print(txt)
         cat("\napollo_HB")
-        cat("\n--------------\n")
+        cat("\n---------\n")
         print(model$apollo_HB)
+        ### start changes 12 April 2023
+        if (length(model[["HB_names_nonrandom_params"]]) > 0) {
+          cat("\nNon-random parameters:")
+          cat("\n----------------------n")
+          cat(paste0(model[["HB_names_nonrandom_params"]], "\n", collapse = ""))
+        }
+        if (length(model[["HB_names_random_params"]]) > 0) {
+          cat("\nRandom parameters (Distribution):")
+          cat("\n---------------------------------n")
+          cat(paste0(paste(model[["HB_names_random_params"]], "(", model[["distributions"]], 
+                           ")"), "\n"), collapse = "", sep = "")
+        }
+        if (!is.null(model[["constraints"]])) {
+          cond <- c("<", ">")
+          cat("\nConstraints applied to random parameters (param1 - inequality - param2):")
+          cat("\n------------------------------------------------------------------------\n")
+          for (i in 1:length(model[["constraints"]])) {
+            if (model[["constraints"]][[i]][3] == 0) {
+              cat(model[["HB_names_random_params"]][model[["constraints"]][[i]][1]], 
+                  cond[model[["constraints"]][[i]][2]], 0, 
+                  "\n")
+            }
+            if (model[["constraints"]][[i]][3] != 0) {
+              cat(model[["HB_names_random_params"]][model[["constraints"]][[i]][1]], 
+                  cond[model[["constraints"]][[i]][2]], model[["HB_names_random_params"]][model[["constraints"]][[i]][3]], 
+                  "\n")
+            }
+          }
+        }
+        if (!is.null(model[["pv"]])) {
+          cat("\nPrior Variance-Covariance Matrix:")
+          cat("\n---------------------------------\n")
+          print(model[["pv"]])
+        }
+        ### end changes 12 April 2023
+        
+        
         cat("\n")
         cat("\n\napollo_probabilities")
-        cat("\n--------------------\n")
+        cat("\n----------------------\n")
         txt=capture.output(print(model$apollo_probabilities))
         cat(txt, sep="\n")
       }
       ### end 3 Feb
       
-      ans[["random_mean"]]   <- model$chain_random_mean
-      ans[["random_cov_mean"]] <- model$chain_random_cov_mean
-      ans[["random_cov_sd"]] <- model$chain_random_cov_sd
-      ans[["random_coeff_summary"]]     <- model$random_coeff_summary
-      ans[["posterior"]]     <- model$posterior_mean
-      ans[["random_coeff_covar"]]     <- model$random_coeff_covar
-      ans[["random_coeff_corr"]]     <- model$random_coeff_corr
+      ans[["random_mean"]]   <- model$HB_chains_normals_means
+      ans[["random_cov_mean"]] <- model$HB_chains_normals_mean_of_covar
+      ans[["random_cov_sd"]] <- model$HB_chains_normals_sd_of_covar
+      ans[["HB_random_params_mean_sd"]]     <- model$HB_random_params_mean_sd
+      ans[["posterior"]]     <- model$HB_posterior_means_summary
+      ans[["HB_random_params_covar"]]     <- model$HB_random_params_covar
+      ans[["HB_random_params_corr"]]     <- model$HB_random_params_corr
     }    
     return(invisible(ans))
   }
@@ -358,16 +435,16 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   if(length(dropcolumns)>0) output = output[,-dropcolumns, drop=FALSE]
   
   cat("LL(start)                                   : ",round(model$LLStart,2),"\n", sep="")
-  if(length(model$LLout)==1) cat("LL at equal shares, LL(0)                   : ",ifelse(!anyNA(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
-  if(length(model$LLout)>1 ) cat("LL (whole model) at equal shares, LL(0)     : ",ifelse(!anyNA(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
-  if(length(model$LLout)==1) cat("LL at observed shares, LL(C)                : ",ifelse(!anyNA(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
-  if(length(model$LLout)>1 ) cat("LL (whole model) at observed shares, LL(C)  : ",ifelse(!anyNA(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
+  if(length(model$LLout)==1) cat("LL at equal shares, LL(0)                   : ",ifelse(is.numeric(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
+  if(length(model$LLout)>1 ) cat("LL (whole model) at equal shares, LL(0)     : ",ifelse(is.numeric(model$LL0[1]),round(model$LL0[1],2),"Not applicable"),"\n", sep="")
+  if(length(model$LLout)==1) cat("LL at observed shares, LL(C)                : ",ifelse(is.numeric(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
+  if(length(model$LLout)>1 ) cat("LL (whole model) at observed shares, LL(C)  : ",ifelse(is.numeric(model$LLC[1]),round(model$LLC[1],2),"Not applicable"),"\n", sep="")
   if(length(model$LLout)==1) cat("LL(final)                                   : ",round(model$maximum,2),"\n",sep="")
   if(length(model$LLout)>1 ) cat("LL(final, whole model)                      : ",round(model$maximum,2),"\n",sep="")
-  cat("Rho-squared vs equal shares                  : ", ifelse(anyNA(model$rho2_0   ), "Not applicable", round(model$rho2_0   , 4)),"\n")
-  cat("Adj.Rho-squared vs equal shares              : ", ifelse(anyNA(model$adjRho2_0), "Not applicable", round(model$adjRho2_0, 4)),"\n")
-  cat("Rho-squared vs observed shares               : ", ifelse(anyNA(model$rho2_C   ), "Not applicable", round(model$rho2_C   , 4)),"\n")
-  cat("Adj.Rho-squared vs observed shares           : ", ifelse(anyNA(model$adjRho2_C), "Not applicable", round(model$adjRho2_C, 4)),"\n")
+  cat("Rho-squared vs equal shares                  : ", ifelse(!is.numeric(model$rho2_0   ), "Not applicable", round(model$rho2_0   , 4)),"\n")
+  cat("Adj.Rho-squared vs equal shares              : ", ifelse(!is.numeric(model$adjRho2_0), "Not applicable", round(model$adjRho2_0, 4)),"\n")
+  cat("Rho-squared vs observed shares               : ", ifelse(!is.numeric(model$rho2_C   ), "Not applicable", round(model$rho2_C   , 4)),"\n")
+  cat("Adj.Rho-squared vs observed shares           : ", ifelse(!is.numeric(model$adjRho2_C), "Not applicable", round(model$adjRho2_C, 4)),"\n")
   cat("AIC                                         : ",round(model$AIC, 2),"\n")
   cat("BIC                                         : ",round(model$BIC, 2),"\n")
   
@@ -388,7 +465,7 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   }
   
   cat("\n")
-  cat("Estimated parameters                        :  ", model$nFreeParams,"\n", sep="")
+  cat("Estimated parameters                        : ", model$nFreeParams,"\n", sep="")
   #cat("Norm of the gradient at optimum  : ",round( sqrt(sum(model$gradient^2)),2), "\n\n")
   f <- function(t){
     tmpH <- floor(t/60^2)
@@ -401,14 +478,22 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   cat("Time taken (hh:mm:ss)                       : ",f(model$timeTaken),"\n")
   cat("     pre-estimation                         : ",f(model$timePre),"\n")
   cat("     estimation                             : ",f(model$timeEst),"\n")
-  cat("     post-estimation                        : ",f(model$timePost),"\n")
-  if(length(grep('successful', model$message))==0) tmp <- paste0("(",model$message,")") else tmp <- ""
-  cat("Iterations                                  : ",model$nIter, tmp, "\n")
-  if(model$bootstrapSE>0) cat("Number of bootstrap repetitions             : ", model$bootstrapSE, "\n")
-  if(!is.null(model$eigValue) && !anyNA(model$eigValue)){
-    cat("Min abs eigenvalue of Hessian               : ",round(min(abs(model$eigValue)),6),"\n")
-    if(any(model$eigValue>0)) apollo_print("Some eigenvalues of Hessian are positive, indicating potential problems!") 
+  if(!is.null(model$nIterPrescaling) && (model$nIterPrescaling>0 & model$nIterPostscaling>0)){
+    cat("          initial estimation                : ",f(model$timeEstPrescaling), "\n")
+    cat("          estimation after rescaling        : ",f(model$timeEstPostscaling), "\n")
   }
+  cat("     post-estimation                        : ",f(model$timePost),"\n")
+  if(!is.null(model$successfulEstimation) && !model$successfulEstimation) tmp <- paste0("(",model$message,")") else tmp <- ""
+  cat("Iterations                                  : ",model$nIter, tmp, "\n")
+  if(!is.null(model$nIterPrescaling) && (model$nIterPrescaling>0 & model$nIterPostscaling>0)){
+    cat("     initial estimation                     : ",model$nIterPrescaling, "\n")
+    cat("     estimation after rescaling             : ",model$nIterPostscaling, "\n")
+  }
+  if(model$bootstrapSE>0) cat("Number of bootstrap repetitions             : ", model$bootstrapSE, "\n")
+  #if(!is.null(model$eigValue) && !anyNA(model$eigValue)){
+  #  cat("Min abs eigenvalue of Hessian               : ",round(min(abs(model$eigValue)),6),"\n")
+  #  if(any(model$eigValue>0)) apollo_print("Some eigenvalues of Hessian are positive, indicating potential problems!") 
+  #}
   
   # Printing of constraints, if used
   cat('\n')
@@ -422,7 +507,7 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
   cat("\n")
   
   if(!printClassical & anyNA(model$se[!(names(model$estimate) %in% model$apollo_fixed)]) ){
-    apollo_print('WARNING: Classical standard errors could not be calculated for some parameters. This could point to an identification or estimation problem.')
+    apollo_print('Classical standard errors could not be calculated for some parameters. This could point to an identification or estimation problem.', type="w")
   }
   
   if(scaling_used) apollo_print("These outputs have had the scaling used in estimation applied to them.")
@@ -532,35 +617,35 @@ apollo_modelOutput=function(model, modelOutput_settings=NA){
     colnames(txt)="Value"
     print(txt)
     cat("\nHessian routines attempted")
-    cat("\n--------------\n")
+    cat("\n--------------------------\n")
     cat(model$hessianMethodsAttempted)
     cat("\n")
     if(!is.null(model$scaling) && !all(model$scaling==1)){
       cat("\nScaling in estimation")
-      cat("\n--------------\n")
+      cat("\n---------------------\n")
       txt=as.matrix(model$scaling)
       colnames(txt)="Value"
       print(txt)}
     if(!is.null(model$hessianScaling) && !all(model$hessianScaling==1)){
       cat("\nScaling used in computing Hessian")
-      cat("\n--------------\n")
+      cat("\n---------------------------------\n")
       txt=as.matrix(model$hessianScaling)
       colnames(txt)="Value"
       print(txt)}
     if(is.function(model$apollo_randCoeff)){
       cat("\n\napollo_randCoeff")
-      cat("\n----------------\n")
+      cat("\n------------------\n")
       txt=capture.output(print(model$apollo_randCoeff))
       #cat(txt[1:(length(txt)-1)],sep="\n")}
       cat(txt, sep="\n")}
     if(is.function(model$apollo_lcPars)){
       cat("\n\napollo_lcPars")
-      cat("\n-------------\n")
+      cat("\n---------------\n")
       txt=capture.output(print(model$apollo_lcPars))
       #cat(txt[1:(length(txt)-1)],sep="\n")}
       cat(txt, sep="\n")}
     cat("\n\napollo_probabilities")
-    cat("\n--------------------\n")
+    cat("\n----------------------\n")
     txt=capture.output(print(model$apollo_probabilities))
     #cat(txt[1:(length(txt)-1)],sep="\n")
     cat(txt, sep="\n")
