@@ -106,26 +106,25 @@
 #'                                                           validation sample 
 #'                                                           (>1). Default is 
 #'                                                           0.1.}
-#'                                     \item{rmseObs}{Character vector. Used to 
-#'                                                    calculate Root Mean 
-#'                                                    Squared Error (RMSE) of 
-#'                                                    prediction. It should 
-#'                                                    contain the name of the 
-#'                                                    columns with the observed 
-#'                                                    outcomes in the database, 
-#'                                                    in the same order than as 
-#'                                                    returned by 
-#'                                                    apollo_probabilities when 
-#'                                                    used with
-#'                                                    functionality="prediction". 
-#'                                                    If omitted or NULL, no 
-#'                                                    RMSE is calculated.
-#'                                                    It works only for models 
-#'                                                    with a single component.}
+#'                                     \item{rmse}{Character matrix with two
+#'                                                 columns. Used to calculate 
+#'                                                 Root Mean Squared Error (RMSE) 
+#'                                                 of prediction. The first 
+#'                                                 column must contain the names 
+#'                                                 of observed outcomes in the 
+#'                                                 database. The second column 
+#'                                                 must contain the names of the 
+#'                                                 predicted outcomes as 
+#'                                                 returned by 
+#'                                                 \code{apollo_prediction}. 
+#'                                                 If omitted or NULL, no RMSE 
+#'                                                 is calculated. This only 
+#'                                                 works for models with a 
+#'                                                 single component.}
 #'                                   }
-#' @return A matrix with the average log-likelihood per observation for both the estimation and validation 
-#'         samples, for each repetition. Two additional files with further details are written to the
-#'         working/output directory.
+#' @return A matrix with the average log-likelihood per observation for both the 
+#'         estimation and validation samples, for each repetition. Two additional 
+#'         files with further details are written to the working/output directory.
 #' @export
 #' @importFrom maxLik maxLik
 #' @importFrom utils read.csv
@@ -140,19 +139,27 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
                                outOfSample_settings=list(nRep=10,
                                                          validationSize=0.1,
                                                          samples=NA, 
-                                                         rmseObs=NULL)){
+                                                         rmse=NULL)){
   ### Set missing settings to default values
-  default <- list(estimationRoutine="bfgs", maxIterations=200, writeIter=TRUE, hessianRoutine="none", printLevel=3L, silent=FALSE)
-  tmp <- names(default)[!(names(default) %in% names(estimate_settings))] # options missing in estimate_settings
+  default <- list(estimationRoutine="bfgs", maxIterations=200, writeIter=FALSE, 
+                  hessianRoutine="none", printLevel=3L, silent=TRUE)
+  tmp <- names(default)[!(names(default) %in% names(estimate_settings))]
   for(i in tmp) estimate_settings[[i]] <- default[[i]]
-  default <- list(nRep=10, validationSize=0.1, samples=NA)
-  tmp <- names(default)[!(names(default) %in% names(outOfSample_settings))] # options missing in estimate_settings
+  default <- list(nRep=10, validationSize=0.1, samples=NA, rmse=NULL)
+  tmp <- names(default)[!(names(default) %in% names(outOfSample_settings))]
   for(i in tmp) outOfSample_settings[[i]] <- default[[i]]
   
-  ### Write original apollo_inputs to disk before changing it, and make sure to restore it before finishing
-  saveRDS(apollo_inputs, file=paste0(tempdir(), "\\", apollo_inputs$apollo_control$modelName,"_outOfSample"))
+  # Start clock
+  starttime <- Sys.time()
+  
+  ### Write original apollo_inputs to disk before changing it, and make sure to 
+    # restore it before finishing
+  saveRDS(apollo_inputs, 
+          file=paste0(tempdir(), "\\", apollo_inputs$apollo_control$modelName, 
+                      "_outOfSample"))
   on.exit({
-    tmp <- paste0(tempdir(), "\\", apollo_inputs$apollo_control$modelName,"_outOfSample")
+    tmp <- paste0(tempdir(), "\\", apollo_inputs$apollo_control$modelName,
+                  "_outOfSample")
     apollo_inputs <- tryCatch(readRDS(tmp), error=function(e) NULL)
     if(!is.null(apollo_inputs)){
       tmp2 <- globalenv()
@@ -170,7 +177,9 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
   apollo_randCoeff <- apollo_inputs$apollo_randCoeff
   apollo_lcPars    <- apollo_inputs$apollo_lcPars
   workInLogs       <- apollo_inputs$apollo_control$workInLogs
-  if(!is.null(apollo_inputs$apollo_control$seed)) seed <- apollo_inputs$apollo_control$seed + 3 else seed <- 13 + 3
+  if(!is.null(apollo_inputs$apollo_control$seed)){
+    seed <- apollo_inputs$apollo_control$seed + 3
+  } else seed <- 13 + 3
   
   # Extract values from estimate_settings and outOfSample_settings
   estimationRoutine <- estimate_settings$estimationRoutine
@@ -178,40 +187,66 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
   nRep              <- outOfSample_settings$nRep
   validationSize    <- outOfSample_settings$validationSize
   samples           <- outOfSample_settings$samples
-  rmseObs           <- outOfSample_settings$rmseObs
+  rmse           <- outOfSample_settings$rmse
   
   # Validate arguments
   apollo_checkArguments(apollo_probabilities,apollo_randCoeff,apollo_lcPars)
   estimationRoutine <- tolower(estimationRoutine)
-  if( !(estimationRoutine %in% c("bfgs","bhhh", "nr")) ) stop("Invalid estimationRoutine. Use 'bfgs', 'bhhh' or 'nr'.")
-  if( (length(apollo_fixed) > 0) & any(!(apollo_fixed %in% names(apollo_beta))) ) stop("Some parameters included in 'apollo_fixed' are not included in 'apollo_beta'")
-  maxIterations <- round(maxIterations,0)
-  if(maxIterations < 1) stop("Need at least one iteration!")
-  if(workInLogs != TRUE) workInLogs=FALSE
-  if(validationSize < 0) stop("validationSize must be positive.")
-  if(apollo_control$mixing){
-    if(anyNA(apollo_draws)) stop("Argument 'apollo_draws' must be provided when estimating mixture models.")
-    if(!is.function(apollo_randCoeff)) stop("Argument 'apollo_randCoeff' must be provided when estimating mixture models.")
-  }
+  maxIterations     <- round(maxIterations, 0)
+  test <- estimationRoutine %in% c("bfgs","bgw","bhhh", "nr")
+  if(!test) stop("SYNTAX ISSUE - Invalid estimationRoutine.",
+                 "Use 'bfgs', 'bgw', 'bhhh' or 'nr'.")
+  test <- length(apollo_fixed)==0 || all(apollo_fixed %in% names(apollo_beta))
+  if(!test) stop("SYNTAX ISSUE - Some parameters included in 'apollo_fixed' ",
+                 "are not included in 'apollo_beta'")
+  if(maxIterations < 1) stop("SYNTAX ISSUE - Need at least one iteration!")
+  if(workInLogs != TRUE) workInLogs <- FALSE
+  if(validationSize < 0) stop("SYNTAX ISSUE - validationSize must be positive.")
+  test <- !apollo_control$mixing || (!anyNA(apollo_draws) && 
+                                       is.function(apollo_randCoeff))
+  if(!test) stop("SYNTAX ISSUE - When using mixture models, objects ", 
+                 "'apollo_draws' and 'apollo_randCoeff' must be created by ", 
+                 "the user")
   if(!anyNA(samples)){
     if(is.data.frame(samples)) samples <- as.matrix(samples)
-    if(!is.matrix(samples)) stop("The 'samples' argument must be a matrix.")
-    if(nrow(samples)!=nrow(database)) stop("The 'samples' matrix must have as many rows as the database.")
-    if(!all(samples %in% 0:1)) stop("The 'samples' matrix must only contain values equal to 0 or 1.")
-    if(ncol(samples)<2) stop("The 'samples' matrix must have at least two columns.")
+    test <- is.matrix(samples) && nrow(samples)==nrow(database) && 
+      all(samples %in% 0:1) && ncol(samples)>=2
+    if(!test) stop("INPUT ISSUE - The 'samples' argument must be a numeric ", 
+                   "or logical matrix with the same number of rows as the ", 
+                   "database, at least two columns, and only 0/1 elements.")
   }
-  
-  # Start clock
-  starttime <- Sys.time()
-  
-  apollo_print(paste0(nRep, " separate runs will be conducted, each using a random subset of ",round((1-validationSize)*100,2),"% for estimation and the remainder for validation."))
-
-  # Initial report
   indivs  <- unique(database[,apollo_control$indivID])
   nIndivs <- length(indivs)
   if(anyNA(samples)){
-    if(validationSize < 1) validationSize <- round(outOfSample_settings$validationSize*nIndivs)
-    if(!(1<=validationSize & validationSize<nIndivs)) stop("validationSize must be between 1 and (nIndivs-1).")
+    if(validationSize<1) validationSize <- round(validationSize*nIndivs)
+    if(validationSize>nIndivs) stop("SYNTAX ISSUE - 'validationSize' must be ", 
+                                    "between 1 and (nIndivs-1).")
+  }
+  apollo_print("Testing likelihood function.")
+  llComponents <- apollo_probabilities(apollo_beta, apollo_inputs, functionality="output")
+  if(!is.null(rmse)){
+    test <- length(llComponents)==1
+    if(!test) stop("SYNTAX ISSUE - The model contains more than one component, ", 
+                   "but RMSE can only be calculated for single-component models.")
+    test <- is.character(rmse)
+    test <- test && (is.vector(rmse) || (is.matrix(rmse) && ncol(rmse)==2))
+    if(!test) stop("SYNTAX ISSUE - Argument 'rmse' must be a character ", 
+                   "matrix with 2 columns, or a character vector.")
+    if(is.vector(rmse)) rmse <- matrix(rmse, nrow=length(rmse), ncol=2)
+    colnames(rmse) <- c("obs", "for")
+    test <- all(rmse[,"obs"] %in% names(apollo_inputs$database)) &&
+      all(sapply(apollo_inputs$database[,rmse[,"obs"]], is.numeric))
+    if(!test) stop("INPUT ISSUE - All outcomes named in rmse must exist ", 
+                   "in the database, and be numeric.")
+  }
+  
+  
+  # Initial report
+  apollo_print(paste0(nRep, " separate runs will be conducted, each using a ",
+                      "random subset of ", round(100*validationSize/nIndivs, 0), 
+                      "% of individuals for estimation, and the remainder ", 
+                      "for validation."))
+  if(anyNA(samples)){
     apollo_print("Number of individuals")
     apollo_print(paste0("- for estimation   : ", nIndivs - validationSize))
     apollo_print(paste0("- for forecasting  : ", validationSize))
@@ -221,40 +256,44 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
     nPre <- colSums(samples)
     if(all(nPre==nPre[1])) nPre <- nPre[1]
     apollo_print("Number of observations")
-    apollo_print(paste0("- for estimation : ", ifelse(length(nPre)==1, nrow(samples) - nPre, "Changes by sample")))
-    apollo_print(paste0("- for forecasting: ", ifelse(length(nPre)==1, nPre, "Changes by sample")))
+    apollo_print(paste0("- for estimation : ", ifelse(length(nPre)==1,
+                                                      nrow(samples) - nPre, 
+                                                      "Changes by sample")))
+    apollo_print(paste0("- for forecasting: ", ifelse(length(nPre)==1, nPre, 
+                                                      "Changes by sample")))
     apollo_print(paste0("Number of individuals in sample: ", nIndivs))
   }
   
-  # Get number of LL components in model
-  apollo_print("Preparing loop.")
-  llComponents       <- apollo_probabilities(apollo_beta, apollo_inputs, functionality="output")
-  paramStack         <- matrix(0, nrow=nRep, ncol=length(apollo_beta) , dimnames=list(c(), names(apollo_beta)))
-  llInSampleStack    <- matrix(0, nrow=nRep, ncol=length(llComponents), dimnames=list(c(), paste0("inSample_", names(llComponents))) )
-  llOutOfSampleStack <- matrix(0, nrow=nRep, ncol=length(llComponents), dimnames=list(c(), paste0("outOfSample_", names(llComponents))) )
+  # Initialise matrices to store results
+  cNam               <- names(llComponents)
+  paramStack         <- matrix(0, nrow=nRep, ncol=length(apollo_beta) , 
+                               dimnames=list(c(), names(apollo_beta)))
+  llInSampleStack    <- matrix(0, nrow=nRep, ncol=length(llComponents), 
+                               dimnames=list(c(), paste0("inSample_", cNam)))
+  llOutOfSampleStack <- matrix(0, nrow=nRep, ncol=length(llComponents), 
+                               dimnames=list(c(), paste0("outOfSample_", cNam)))
   nObsStack          <- rep(0,nRep)
   if(anyNA(samples)){
-    samples <- matrix(0, nrow=nrow(database), ncol=nRep, dimnames=list(c(), paste0("sample_",1:nRep)))
+    samples <- matrix(0, nrow=nrow(database), ncol=nRep, 
+                      dimnames=list(NULL, paste0("sample_",1:nRep)))
     set.seed(seed)
-    for(i in 1:nRep) samples[,i] <- database[,apollo_control$indivID] %in% sample(indivs, size=validationSize)
+    for(i in 1:nRep) samples[,i] <- database[,apollo_control$indivID] %in% 
+      sample(indivs, size=validationSize)
   }
+  if(is.character(rmse)){
+    RMSE <- paste0("rmse_", c(rmse[,"obs"], "aggregate"))
+    RMSE <- matrix(0, nrow=nRep, ncol=nrow(rmse) + 1, 
+                   dimnames=list(NULL, RMSE))
+  } else RMSE <- NULL
   rm(llComponents)
   
-  # Check that RMSE can be calculated and initialise if requested
-  if(!is.null(rmseObs)){
-    if(ncol(llInSampleStack)>1) stop("The model contains more than one component, but RMSE can only be calculated for models with a single component.")
-    if(!is.character(rmseObs)) stop("Argument rmseObs should be a character vector.")
-    if(!all(rmseObs %in% names(apollo_inputs$database))) stop("Not all outcomes included in rmsObs exist in the database.")
-    if(!all(sapply(apollo_inputs$database[,rmseObs], is.numeric))) stop("Not all outcomes included in rmseObs are numeric in the database.")
-    RMSE <- paste0("rmse_", c(rmseObs, "aggregate"))
-    RMSE <- matrix(0, nrow=nRep, ncol=length(rmseObs) + 1, dimnames=list(NULL, RMSE))
-  } else RMSE <- NULL
-  
   # Check if there are previous results. If so, load them
-  fileNameParams <- paste0(apollo_control$outputDirectory, apollo_control$modelName, "_outOfSample_params.csv")
-  fileNameSample <- paste0(apollo_control$outputDirectory, apollo_control$modelName, "_outOfSample_samples.csv")
+  fileNameParams <- paste0(apollo_control$outputDirectory, 
+                           apollo_control$modelName, "_outOfSample_params.csv")
+  fileNameSample <- paste0(apollo_control$outputDirectory, 
+                           apollo_control$modelName, "_outOfSample_samples.csv")
   nRun <- 0
-  if(file.exists(fileNameParams) & file.exists(fileNameSample)){
+  if(file.exists(fileNameParams) && file.exists(fileNameSample)){
     apollo_print("Old output files found, they will be recycled.")
     # Read params
     tmp <- as.matrix(read.csv(fileNameParams))
@@ -262,48 +301,66 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
     tmp2 <- tmp[, grep('^inSample_'   , colnames(tmp)), drop=FALSE] # llInSampleStack
     tmp3 <- tmp[, grep('^outOfSample_', colnames(tmp)), drop=FALSE] # llOutOfSampleStack
     tmp4 <- as.matrix(read.csv(fileNameSample)) # samples
+    tmp5 <- tmp[, grep("^rmse_"       , colnames(tmp)), drop=FALSE] # RMSE
     nRun <- sum(tmp3[,ncol(tmp3)]!=0)
     if(nrow(tmp1)>nRun) tmp1 <- tmp1[1:nRun,] 
     if(nrow(tmp2)>nRun) tmp2 <- tmp2[1:nRun,] 
     if(nrow(tmp3)>nRun) tmp3 <- tmp3[1:nRun,] 
     if(ncol(tmp4)>nRun) tmp4 <- tmp4[, 1:nRun]
+    if(ncol(tmp5)>nRun) tmp5 <- tmp5[1:nRun,]
     # Check that result files match
-    test <- ncol(tmp1)==ncol(paramStack) && ncol(tmp2)==ncol(llInSampleStack) && ncol(tmp3)==ncol(llOutOfSampleStack)
+    test <- nRun>0 && ncol(tmp1)==ncol(paramStack)
+    test <- test && ncol(tmp2)==ncol(llInSampleStack)
+    test <- test && ncol(tmp3)==ncol(llOutOfSampleStack)
     test <- test && nrow(tmp4)==nrow(database)
     if(test){
-      apollo_print(paste0(nRun, ' repetitions recovered from old result files. ', nRep, ' new repetitions will be added.'))
+      apollo_print(paste0(nRun, ' repetitions recovered from old result files. ', 
+                          nRep, ' new repetitions will be added.'))
       nRep <- nRun + nRep
-      # Expand paramStack, llInSampleStack, llOutOfSampleStack, nObsStack and samples to fit old results
+      # Expand paramStack, llInSampleStack, llOutOfSampleStack, nObsStack and 
+      # samples to fit old results
       paramStack         <- rbind(tmp1, paramStack)
       llInSampleStack    <- rbind(tmp2, llInSampleStack)
       llOutOfSampleStack <- rbind(tmp3, llOutOfSampleStack)
-      samples            <- cbind(tmp4, samples); colnames(samples) <- paste0("sample_",1:nRep)
+      samples            <- cbind(tmp4, samples)
+      colnames(samples)  <- paste0("sample_",1:nRep)
       set.seed(seed)
-      for(i in 1:nRep){
-        tmp <- sample(indivs, size=validationSize)
-        if(i>nRun) samples[,i] <- database[,apollo_control$indivID] %in% tmp
-      }
+      for(i in 1:nRep) if(i>nRun) samples[,i] <- database[,apollo_control$indivID] %in% 
+        sample(indivs, size=validationSize)
       nObsStack          <- nrow(database) - colSums(samples)
+      if(!is.null(RMSE)) RMSE <- rbind(tmp5, RMSE)
     } else { 
       nRun <- 0
-      apollo_print("Old result files do not match current model, so they will be overwritten.")
+      apollo_print("Old result files do not match current model, or contained ", 
+                   "no completed runs, so they will be overwritten.")
     }
     rm(tmp, tmp1, tmp2, tmp3, tmp4, test)
   }
-  if(nRun>=nRep) stop("All requested repetitions already exist in file fileNameParams.")
+  if(nRun>=nRep) stop("INPUT ISSUE - All requested repetitions already exist ", 
+                      "in file ", fileNameParams)
   
   # OUT OF SAMPLE LOOP
-  apollo_print(paste0("Estimated parameters and log-likelihoods for each sample will be written to: ", fileNameParams))
-  apollo_print(paste0("The matrix defining the observations used in each repetition will be written to: ", fileNameSample))
+  apollo_print(paste0("Estimated parameters and log-likelihoods for each ",
+                      "sample will be written to: ", fileNameParams))
+  apollo_print(paste0("The matrix defining the observations used in each ", 
+                      "repetition will be written to: ", fileNameSample))
   apollo_print("\n")
   for(i in (nRun + 1):nRep){
     
     # Filter database and create draws
     database2   <- database[samples[,i]==0,]
-    apollo_inputs <- apollo_validateInputs(database=database2, silent=TRUE, recycle=TRUE) # used to be apollo_inputs2
-    apollo_inputs$apollo_control$noDiagnostics <- TRUE # used to be apollo_inputs2
-    apollo_inputs$apollo_control$noValidation  <- TRUE # used to be apollo_inputs2
-    #if(apollo_control$mixing) apollo_inputs$draws <- apollo_makeDraws(apollo_inputs, silent=TRUE) # used to be apollo_inputs2
+    apollo_inputs <- apollo_validateInputs(
+      apollo_beta      = apollo_beta, 
+      apollo_fixed     = apollo_fixed, 
+      database         = database2  , 
+      apollo_control   = apollo_control, 
+      apollo_HB        = apollo_inputs$apollo_HB, 
+      apollo_randCoeff = apollo_inputs$apollo_randCoeff, 
+      apollo_lcPars    = apollo_inputs$apollo_lcPars, 
+      silent           = TRUE,
+      recycle          = TRUE)
+    apollo_inputs$apollo_control$noDiagnostics <- TRUE
+    apollo_inputs$apollo_control$noValidation  <- TRUE
     
     # Estimate
     apollo_print(paste0('Estimation cycle ', i, ' (', nrow(database2), ' obs.)'))
@@ -321,15 +378,17 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
     }
     
     # Check convergence
-    succesfulEstimation <- FALSE
+    successfulEstimation <- FALSE
     if(exists("model")){
-      if(estimationRoutine=="bfgs" & model$code==0) succesfulEstimation <- TRUE
-      if(estimationRoutine=="bhhh" & (model$code %in% c(2,8)) ) succesfulEstimation <- TRUE
-      if(estimationRoutine=="nr" && model$code<=2) succesfulEstimation <- TRUE
+      test <- estimationRoutine=="bfgs" & model$code==0
+      test <- test || ( estimationRoutine=="bgw" && model$code %in% c(3,4,5,6) )
+      test <- test || ( estimationRoutine=="bhhh" & (model$code %in% c(2,8)) )
+      test <- test || ( estimationRoutine=="nr" && model$code<=2 )
+      if(test) successfulEstimation <- TRUE
     }
     
     # Write results
-    if(succesfulEstimation){
+    if(successfulEstimation){
       
       # Store estimated parameters
       temp <- c(model$estimate, apollo_beta[apollo_fixed])
@@ -337,26 +396,49 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
       paramStack[i,] <- temp
       
       # Store in-sample LL components
-      llin <- apollo_probabilities(model$estimate, apollo_inputs, functionality="output") # used to be apollo_inputs2
-      for(j in 1:ncol(llInSampleStack)) llInSampleStack[i,j] <- ifelse(workInLogs, sum(llin[[j]]), sum(log(llin[[j]])))
+      llin <- apollo_probabilities(model$estimate, apollo_inputs, functionality="output")
+      for(j in 1:ncol(llInSampleStack)) llInSampleStack[i,j] <- ifelse(workInLogs, 
+                                                                       sum(llin[[j]]), 
+                                                                       sum(log(llin[[j]])))
       
       # Store out-of-sample LL components
       database2 <- database[samples[,i]>0,]
-      apollo_inputs <- apollo_validateInputs(database=database2, silent=TRUE, recycle=TRUE) # used to be apollo_inputs2
-      apollo_inputs$apollo_control$noDiagnostics <- TRUE # used to be apollo_inputs2
-      llout <- apollo_probabilities(model$estimate, apollo_inputs, functionality="output") # used to be apollo_inputs2
-      for(j in 1:ncol(llOutOfSampleStack)) llOutOfSampleStack[i,j] <- ifelse(workInLogs, sum(llout[[j]]), sum(log(llout[[j]])))
+      apollo_inputs <- apollo_validateInputs(
+        apollo_beta      = apollo_beta, 
+        apollo_fixed     = apollo_fixed, 
+        database         = database2  , 
+        apollo_control   = apollo_control, 
+        apollo_HB        = apollo_inputs$apollo_HB, 
+        apollo_randCoeff = apollo_inputs$apollo_randCoeff, 
+        apollo_lcPars    = apollo_inputs$apollo_lcPars, 
+        silent           = TRUE,
+        recycle          = TRUE)
+      apollo_inputs$apollo_control$noDiagnostics <- TRUE
+      llout <- apollo_probabilities(model$estimate, apollo_inputs, 
+                                    functionality="output")
+      for(j in 1:ncol(llOutOfSampleStack)){
+        llOutOfSampleStack[i,j] <- ifelse(workInLogs, sum(llout[[j]]), 
+                                          sum(log(llout[[j]])))
+      } 
       
       # Store RMSE
-      if( is.character(rmseObs) ){
+      if( is.character(rmse) ){
         pred <- apollo_prediction(model, apollo_probabilities, apollo_inputs)
-        if( !is.data.frame(pred) ) stop("The model uses an incompatible component type. RMSE cannot be calculated.")
-        pred <- pred[,-(1:2)]  # drop "indivID" and "Observation"
-        if("chosen" %in% names(pred)) pred <- pred[, names(pred)!="chosen"] # drop chosen
-        pred <- pred[, 1:length(rmseObs)] # keep only as many outcomes as rmseObs
-        if(length(pred) < length(rmseObs)) stop("Number of outcomes in rmseObs is bigger than the number of outcomes generated by apollo_prediction.")
-        RMSE[i, 1:length(rmseObs)] <- sqrt(colMeans((pred - apollo_inputs$database[,rmseObs])^2))
-        RMSE[i, 1+length(rmseObs)] <- sqrt(mean((colSums(pred) - colSums(apollo_inputs$database[,rmseObs]))^2))
+        if( !is.data.frame(pred) ) stop("INCORRECT FUNCTION/SETTING USE - The ", 
+                                        "model uses an incompatible component ", 
+                                        "type. RMSE cannot be calculated.")
+        test <- all(rmse[,"for"] %in% names(pred))
+        if(!test) stop("INPUT ISSUE - The requested forecasted values in ", 
+                       "argument 'rmse' are not generated by the model.")
+        pred <- pred[, rmse[,"for"]] # keep only relevant forecasts
+        obse <- apollo_inputs$database[,rmse[,"obs"]]
+        if(nrow(rmse)==1){
+          RMSE[i, 1:nrow(rmse)] <- sqrt(mean((pred - obse)^2))
+          RMSE[i, 1+nrow(rmse)] <- sum(pred) - sum(obse)
+        } else {
+          RMSE[i, 1:nrow(rmse)] <- sqrt(colMeans((pred - obse)^2))
+          RMSE[i, 1+nrow(rmse)] <- sqrt(mean((colSums(pred) - colSums(obse))^2))
+        }
       }
       
       # Save results from cross-validation iteration
@@ -371,8 +453,9 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
       apollo_print("Estimation results written to file.")
     } else {
       # Report error but continue with next iteration
-      apollo_print(paste0("ERROR: Estimation failed in cycle ", i, "."))
-      if(estimationRoutine=="bfgs") print(as.matrix(round(get("lastFuncParam", envir=globalenv()),4)))
+      apollo_print(paste0("Estimation failed in cycle ", i, "."), type="w")
+      if(estimationRoutine=="bfgs") print(as.matrix(round(get("lastFuncParam", 
+                                                              envir=globalenv()),4)))
     }
     
   }
@@ -383,21 +466,19 @@ apollo_outOfSample <- function(apollo_beta, apollo_fixed,
   apollo_print(paste0("Processing time: ", format(timeTaken)))
   apollo_print("\n")
   
-  output_matrix=cbind(llInSampleStack[,"inSample_model"]/nObsStack,
-                      llOutOfSampleStack[,"outOfSample_model"]/(nrow(database)-nObsStack))
-  output_matrix=cbind(output_matrix,100*(output_matrix[,2]-output_matrix[,1])/abs(output_matrix[,1]))
   
+  avgObsLL_est = llInSampleStack[,"inSample_model"]/nObsStack
+  avgLLObs_val = llOutOfSampleStack[,"outOfSample_model"]/(nrow(database)-nObsStack)
+  percentDiff  = 100*(avgLLObs_val-avgObsLL_est)/avgObsLL_est
+  M <- cbind(avgObsLL_est, avgLLObs_val, percentDiff)
+  M <- rbind(M, Average = colMeans(M))
+  tmp <- colnames(M)
+  colnames(M) <- c("LL per obs in estimation sample", 
+                   "LL per obs in validation sample", 
+                   "% difference")
+  apollo_print("Summary of cross-validation:")
+  apollo_print(M)
+  colnames(M) <- tmp
   
-  output_matrix=rbind(output_matrix,colMeans(output_matrix))
-  
-  output_matrix=data.frame(output_matrix)
-  output_matrix[,1:2]=round(output_matrix[,1:2],4)
-  output_matrix[,3]=round(output_matrix[,3],2)
-  rownames(output_matrix)[nrow(output_matrix)]="Average"
-  colnames(output_matrix)=c("LL per obs in estimation sample","LL per obs in validation sample","% difference")
-  
-  cat("Outputs of out of sample testing:\n")
-  print(output_matrix)
-  
-  invisible(t(output_matrix))
+  return(invisible(M))
 }
